@@ -7,7 +7,7 @@
 
 # Soft-thresholding operator
 St <- function(lambda, X) {
-    s <- function(lambda0, x) {
+    st <- function(lambda0, x) {
         if (x > lambda0) {
             result0 <- x - lambda0
         } else if (x < (-1) * lambda0) {
@@ -16,17 +16,19 @@ St <- function(lambda, X) {
 
         return(result0)
     }
-    result <- apply(X, 1, s, lambda0 = lambda)
+    result <- apply(X, 1, st, lambda0 = lambda)
     return(result)
 }
 
 
 # Main algorithm
-proximal_gradient_descent <- function(X, Y, lambda, step_size, n_iter) {
+proximal_gradient_descent <- function(X, Y, lambda, n_iter) {
     # --------- Initialize parameter ---------
     p <- ncol(X)
     parameters <- numeric(p)
 
+    # --------- Run ISTA for n_iter iterations ---------
+    step_size <- 1 / norm(X, "2") ** 2
     for (i in 1:n_iter) {
         # Compute the gradient
         grad <- t(-X) %*% (Y - X %*% parameters)
